CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                            C
C     PROGRAM F77EXAMPLE.F                                                   C
C                                                                            C
C     THIS PROGRAM COMPUTES THE MEAN VALUE AND THE STANDARD DEVIATION        C
C     OF THE X(U+UBAR), X(D+DBAR), X(S+SBAR) AND XGLUON POLARIZED PDF        C
C     COMBINATIONS AT FIXED ENERGY SCALE Q2 FOR DIFFERENT VALUES OF X        C
C     FROM A MONTE CARLO ENSEMBLE OF POLARIZED NNPDFs.                       C
C     RESULTS ARE STORED IN .res FILES.                                      C
C                                                                            C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

      PROGRAM EXAMPLE_PDF
      IMPLICIT NONE

      INTEGER IPDF, NTOTPDF
      PARAMETER(NTOTPDF=4)
      INTEGER IREP, NREP, IPT, NPOINTS
      PARAMETER(NPOINTS=100)
      DOUBLE PRECISION X, XMIN, XMAX, DELTAX, Q2
      PARAMETER(XMIN=1D-3,XMAX=1D0)
      DOUBLE PRECISION XU, XD, XS, XG
      DOUBLE PRECISION XPDF(NTOTPDF), XPDF_AV(NTOTPDF), XPDF_ER(NTOTPDF)
      CHARACTER*70 WRAPFILE
      
*     Set the path and name of the PDF grid to be initialized
      WRAPFILE="/usr/local/share/lhapdf/PDFsets/NNPDFpol10_100.LHgrid"

*     Load the PDF grid from file
      CALL INITNNPDFSET(wrapfile)

*     Initialize the number of PDF members in the grid
      CALL NUMBERNNPDF(NREP)

*     Set the Q2 scale
      Q2=1d0 ![GeV]

*     Set the incremental deltax 
      DELTAX=(XMAX-XMIN)/NPOINTS

*     Write to a file the central value of the available 
*     polarized PDFs for 100 points linearly spaced in x
      OPEN(UNIT=10,STATUS="UNKNOWN",FILE="xnnpdfpol_cv_ff.res")

      DO IPT=0, NPOINTS
         
         X=XMIN+IPT*DELTAX
         IREP=0
         CALL NNPDFPOL(X,Q2,IREP,XU,XD,XS,XG)
         WRITE(10,101) IPT, X, XU, XD, XS, XG
      
      ENDDO

      CLOSE(10)
      
*     Write to a file the mean value and the standard deviation
*     of the available polarized PDFs for 100 points linearly 
*     spaced in x using the Monte Carlo recipe
      OPEN(UNIT=11,STATUS="UNKNOWN",FILE="xnnpdfpol_ff.res")

      DO IPT=0, NPOINTS

         DO IPDF=1, NTOTPDF
            XPDF_AV(IPDF)=0d0
            XPDF_ER(IPDF)=0d0
         ENDDO

         X=XMIN+IPT*DELTAX

         DO IREP=1, NREP
            
            CALL NNPDFPOL(X,Q2,IREP,XU,XD,XS,XG)
            XPDF(1)=XU
            XPDF(2)=XD
            XPDF(3)=XS
            XPDF(4)=XG

            DO IPDF=1, NTOTPDF
               XPDF_AV(IPDF)=XPDF_AV(IPDF)+XPDF(IPDF)/DBLE(NREP)
               XPDF_ER(IPDF)=XPDF_ER(IPDF)+XPDF(IPDF)**2d0/DBLE(NREP)
            ENDDO

         ENDDO

         DO IPDF=1, NTOTPDF
            XPDF_ER(IPDF)=DSQRT(XPDF_ER(IPDF)-XPDF_AV(IPDF)**2d0)
         ENDDO

         WRITE(11,102) IPT, X, 
     1        (XPDF_AV(IPDF),XPDF_ER(IPDF),IPDF=1,NTOTPDF)

      ENDDO

      CLOSE(11)


 101  FORMAT(I5,F10.7,4(F15.10))
 102  FORMAT(I5,F10.7,8(F15.10))
      STOP
      END

 










 






 
                                          






 

      



         
   





                                          


